Echoes of the Past : The Hotel Syracuse Historic Ghostwalk (photos) | syracuse.com
Description: The Onondaga Historical Association leads groups through the Hotel Syracuse today on Historic Ghostwalks from 1 - 3:30 p.m.

comments

# Echoes of the Past : The Hotel Syracuse Historic Ghostwalk (photos)

Loading Photo Gallery

Print
David Lassman | dlassman@syracuse.com By David Lassman | dlassman@syracuse.com The Post-Standard
on December 27, 2014 at 4:28 PM, updated December 29, 2014 at 1:59 PM
View/Post Comments

The Onondaga Historical Association leads groups through the Hotel Syracuse today on Historic Ghostwalks from 1 - 3:30 p.m. In what's subtitled 'Suite Stories' people tour many of the public spaces at the hotel as actors play personalities from the hotel's past. The building opened in 1924 and many famous names have been guests. A feature of the event is a view of Carl Roters 40 foot mural above the registration desk which has been covered with mirrors for the last 37 years.

Here's an update from the OHA :
• Reservation can only be made online at www.hotelsyracuseghostwalk.eventbrite.com, not by calling OHA
• There are no walk-ins allowed
• There are a limited amount of tickets being added today, December 29th, at 2 P.M. for the January 3rd tours.

View/Post Comments

## Related Stories

# House of the Week

## Valley views near Hamilton

The house, which sits on 20 acres, overlooks Lake Moraine and hillsides dotted with silos and working farms

More House of the Week homes »

# More CNY Living

- Things to do: Search local events
- Food & Drink: Recipes, reviews & more
- Weddings: Dresses, announcements & more

## Most Read

## Active Discussions

## Best of syracuse.com

Disney magic fills Oncenter War Memorial
New York State of the State address postponed
Study: NY ranks No. 2 in residents moving away